import { 
  select, 
  scaleLinear,
  scaleTime,
  extent, 
  axisLeft, 
  axisBottom,
  line,
  curveBasis,
  max,
  min,
  legend
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue=  d => d.year; 
	const yValue5=  d => d["5_5.9"];
  const yValue6=  d => d["6_6.9"];
  const yValue7=  d => d["7_7.9"];
  const yValue8=  d => d["8.0+"]; 

  const xAxisLabelValue = 'Year';
  const yAxisLabelValue = 'Num of Earthquakes';
	const titleValue = 'Worldwide Earthquake stats 2002-2015';
  const margin = { top: 50, right: 50, bottom: 80, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 6;
  const maxYear = max(data, xValue);
  const minYear = min(data, xValue);
  const maxValue5 = max(data, yValue5);
  const minValue5 = min(data, yValue5);

//定义x轴范围
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
//定义y轴范围
  
	const yScale = scaleLinear()
  	.domain([0, max(data, yValue5)])
  	.range([innerHeight, 0])
  	.nice();
  
  
//create了一个group element G，以后就不用svg了
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
//画出x轴  
  
  const xAxis = 
        axisBottom(xScale)
  		.tickSize(-innerHeight)
  		.tickPadding(15);

//画出y轴 
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
//定义y轴坐标
  
  const yAxisG = g.append('g').call(yAxis);
  
	yAxisG
  	.selectAll('.domain')
  	.remove();
  
  yAxisG.append('text')
  	.attr('class', 'xAxisLabel')
  	.text(yAxisLabelValue)
  	.attr('fill', 'black')
  	.attr('y', -80)
  	.attr('x', -innerHeight/2)
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle');

//定义x轴坐标
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG
   	.select('.domain')
  	.remove();
  
  xAxisG.append('text')
  	.attr('class', 'xAxisLabel')
  	.text(xAxisLabelValue)
  	.attr('fill', 'black')
  	.attr('y', 60)
  	.attr('x', innerWidth/2);
 
 //定义曲线
  
  const lineGenerator5 = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue5(d)))
  	.curve(curveBasis);
  
  const lineGenerator6 = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue6(d)))
  	.curve(curveBasis);
  
  const lineGenerator7 = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue7(d)))
  	.curve(curveBasis);
  
  const lineGenerator8 = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue8(d)))
  	.curve(curveBasis);
  
//画路线
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#FFC300")
    .attr('d', lineGenerator5(data))
  	.attr("data-legend","5_5.9");

  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#FF5733")
    .attr('d', lineGenerator6(data))
  	.attr("data-legend","6_6.9");
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#C70039")
    .attr('d', lineGenerator7(data))
  	.attr("data-legend","7_7.9");
  
  g.append('path')
    .attr('class', 'line-path')
  	.style("stroke", "#900C3F")
    .attr('d', lineGenerator8(data))
  	.attr("data-legend","8.0+");
  
//将title显示出来  
  
  g.append('text')
    .attr('class', 'title')
  	.text(titleValue)
  	.attr('y', -10);
  
//  g.append('legend')
//  	.attr("class","legend")
//  	.attr("transform","translate(50,30)")
//  	.style("font-size","12px")
//  	.call(d3.legend);
  
//    var legend = svg.append("g")
//    .attr("class","legend")
//    .attr("transform","translate(50,30)")
//    .style("font-size","12px")
    
  
//定义legend
  
  //var legend = legendColor()
  //.labelFormat(d3.format(".2f"))
  //.useClass(true)
  //.title("A really really really really really long title")
  //.titleWidth(100)
  //.scale(yScale);

  var legend = g.append("g")
    .attr("class","legend")
    .attr("transform","translate(50,30)")
    .style("font-size","12px")
    .call(d3.legend)

  setTimeout(function() { 
    legend
      .style("font-size","20px")
      .attr("data-style-padding",10)
      .call(d3.legend)
  },1000)
};


//load数据

d3.csv('https://vizhub.com/elaine-xiao/datasets/earthquakes.csv')
  .then(data => {
  	data.forEach(d => {
      d.year = new Date(d.year,0,1);
      d["8.0+"] = +d["8.0+"];
      d["7_7.9"] = +d["